@@ -35,6 +35,7 @@ int mtools_fat_compatibility=0;
 int mtools_ignore_short_case=0;
 int mtools_rate_0=0;
 int mtools_rate_any=0;
+int mtools_no_vfat=0;
 char *country_string=0;
 
 typedef struct switches_l {
@@ -50,6 +51,7 @@ static switches_t switches[] = {
     { "MTOOLS_LOWER_CASE", (caddr_t) & mtools_ignore_short_case, INT },
     { "MTOOLS_FAT_COMPATIBILITY", (caddr_t) & mtools_fat_compatibility, INT },
     { "MTOOLS_SKIP_CHECK", (caddr_t) & mtools_skip_check, INT },
+    { "MTOOLS_NO_VFAT", (caddr_t) & mtools_no_vfat, INT },
     { "MTOOLS_RATE_0", (caddr_t) &mtools_rate_0, INT },
     { "MTOOLS_RATE_ANY", (caddr_t) &mtools_rate_any, INT },
     { "COUNTRY", (caddr_t) &country_string, STRING }
@@ -106,6 +108,7 @@ static switches_t dswitches[]= {
     { "PARTITION", OFFS(partition), INT },
     { "SCSI", OFFS(scsi), INT },
     { "PRIVILEGED", OFFS(privileged), INT },
+    { "VOLD", OFFS(vold), INT },
     { "NOLOCK", OFFS(nolock), INT },
     { "FAT", OFFS(fat_bits), INT },
     { "FAT_BITS", OFFS(fat_bits), INT },
@@ -121,8 +124,8 @@ static switches_t dswitches[]= {
 
 static void syntax(const char *msg)
 {
-    fprintf(stderr,"Syntax error at line %d column %d in file %s: %s\n",
-	    linenumber, token - buffer, filename, msg);
+    fprintf(stderr,"Syntax error at line %d column %ld in file %s: %s\n",
+	    linenumber, (long)(token - buffer), filename, msg);
     exit(1);
 }
 
@@ -539,6 +542,7 @@ static int parse(const char *name, int privilege)
 void read_config(void)
 {
 	char *homedir;
+	char *envConfFile;
 	char conf_file[MAXPATHLEN+sizeof(CFG_FILE1)];
 
 	
@@ -572,6 +576,10 @@ void read_config(void)
 	}
 	memset((char *)&devices[cur_devs],0,sizeof(struct device));
 
+	envConfFile = getenv("MTOOLSRC");
+	if(envConfFile)
+		parse(envConfFile,0);
+
 	/* environmental variables */
 	get_env_conf();
 	if(mtools_skip_check)
@@ -592,6 +600,7 @@ void mtoolstest(int argc, char **argv, int type)
 		       dev->name,dev->fat_bits);
 		printf("\ttracks=%d heads=%d sectors=%d\n",
 		       dev->tracks, dev->heads, dev->sectors);
+		printf("\tvold=%lx\n", (long) dev->vold);
 		printf("\toffset=0x%lx\n", (long) dev->offset);
 		printf("\tpartition=0x%x\n", dev->partition);
 		printf("\tscsi=0x%x\n", dev->scsi);
