@@ -78,12 +78,14 @@ static int dos_loop(MainParam_t *mp, char *arg)
 	have_one = MISSED_ONE;
 	ret = 0;
 
-	Dir =  open_subdir(mp, arg, mp->openflags, 0);
+	Dir =  open_subdir(mp, arg, mp->openflags, 0, 0);
 	if(!Dir)
 		return MISSED_ONE;
 	entry = 0;
 
 	filename = mp->filename;
+	if(!filename[0])
+		filename="*";
 	if(checkForDot(mp, filename)){
 		fprintf(stderr,
 			"This command cannot be applied to \".\" or \"..\"\n");
@@ -91,9 +93,6 @@ static int dos_loop(MainParam_t *mp, char *arg)
 		return MISSED_ONE;
 	}
 
-	if(!filename[0])
-		filename="*";		
-
 	while(entry >= 0){
 		if(got_signal)
 			break;
