@@ -37,7 +37,7 @@ void init_mp(MainParam_t *MainParam);
 int main_loop(MainParam_t *MainParam, char **argv, int argc);
 
 Stream_t *open_subdir(MainParam_t *MainParam, const char *arg, 
-		      int flags, int mode);
+		      int flags, int mode, int lock);
 
 
 #define NEXT_DISK 1
