@@ -26,7 +26,7 @@ void mcd(int argc, char **argv, int type)
 		exit(0);
 	}
 	mp.pathname = pathname;
-	Dir = open_subdir(&mp, argv[1], O_RDONLY, 1);
+	Dir = open_subdir(&mp, argv[1], O_RDONLY, 1, 0);
 	if(!Dir){
 		fprintf(stderr,"No such directory\n");
 		exit(1);
