@@ -327,13 +327,13 @@ void mcopy(int argc, char **argv, int mtype)
 		/* Copying to Dos */
 		
 		have_target = 1;
-		Dir = open_subdir(&arg.mp, argv[argc-1], O_RDWR, 0);
+		Dir = open_subdir(&arg.mp, argv[argc-1], O_RDWR, 0, 0);
 		if(!Dir){
 			fprintf(stderr,"Bad target\n");
 			exit(1);
 		}
 		get_name(argv[argc-1], filename, arg.mp.mcwd);
-		SubDir = descend(Dir, filename, 0, 0);
+		SubDir = descend(Dir, filename, 0, 0, 0);
 		if (!SubDir){
 			/* the last parameter is a file */
 			if (argc - optind != 2){
