@@ -339,7 +339,7 @@ void mdir(int argc, char **argv, int type)
 			arg="";
 		else 
 			arg = argv[i];
-		Dir = open_subdir(&mp, arg, O_RDONLY, 0);
+		Dir = open_subdir(&mp, arg, O_RDONLY, 0, 0);
 		if(!Dir)
 			continue;
 		drive = mp.drivename;
@@ -364,7 +364,7 @@ void mdir(int argc, char **argv, int type)
 		 */
 		get_path(arg,newpath,mp.mcwd,  0);
 		if (strpbrk(mp.filename, "*[?") == NULL &&
-		    ((SubDir = descend(Dir, mp.filename, 0, 0) )) ) {
+		    ((SubDir = descend(Dir, mp.filename, 0, 0, 0) )) ) {
 			static char tmppath[MAX_PATH+5];
 
 			/* Subdirectory */
