@@ -18,7 +18,9 @@
 
 #include <math.h>
 
+#ifndef abs
 #define abs(x) ((x)>0?(x):-(x))
+#endif
 
 extern int errno;
 
@@ -646,6 +648,10 @@ void mformat(int argc, char **argv, int dummy)
 			used_dev.hidden = hs;
 		
 		expand(dev->name, name);
+#ifdef USING_NEW_VOLD
+		strcpy(name, getVoldName(dev, name));
+#endif
+
 #ifdef USE_XDF
 		if(!format_xdf)
 #endif
