@@ -114,12 +114,12 @@ void mlabel(int argc, char **argv, int type)
 	else
 		open_mode = O_RDONLY;
 
-	RootDir = open_subdir(&mp, argv[optind], open_mode, 0);
+	RootDir = open_subdir(&mp, argv[optind], open_mode, 0, 0);
 	if(!RootDir && open_mode == O_RDWR && !clear && !filename[0] &&
 	   ( errno == EACCES || errno == EPERM) ) {
 		show = 1;
 		interactive = 0;
-		RootDir = open_subdir(&mp, argv[optind], O_RDONLY, 0);
+		RootDir = open_subdir(&mp, argv[optind], O_RDONLY, 0, 0);
 	}	    
 	if(!RootDir) {
 		fprintf(stderr, "%s: Cannot initialize drive\n", argv[0]);
