@@ -144,7 +144,7 @@ void mmd(int argc, char **argv, int type)
 	for(i=optind; i < argc; i++){
 		if(got_signal)
 			break;
-		Dir = open_subdir(&arg.mp, argv[i], O_RDWR, 0);
+		Dir = open_subdir(&arg.mp, argv[i], O_RDWR, 0, 0);
 		if(!Dir){
 			fprintf(stderr,"Could not open parent directory\n");
 			exit(1);
