@@ -61,6 +61,13 @@ static struct directory *renameit(char *dosname,
 	if( (dir->attr & 0x10) && arg->targetDir){
 		/* we have a directory here. Change its parent link */
 		Dir = open_file(arg->targetDir, & arg->mp.dir);
+		if(FileIsLocked(Dir)) {
+			fprintf(stderr,
+				"Cannot move directory \'%s%s\' into itself\n",
+				dir->name,dir->ext);
+			FREE(&Dir);
+			return 0;
+		}
 		entry = 0;
 		if(vfat_lookup(Dir,
 			       &parentdir, &entry, 0, "..", ACCEPT_DIR,
@@ -220,13 +227,13 @@ void mmove(int argc, char **argv, int oldsyntax)
 	arg.oldsyntax = oldsyntax;
 
 	if (!oldsyntax){
-		Dir = open_subdir(&arg.mp, argv[argc-1], O_RDWR, 0);
+		Dir = open_subdir(&arg.mp, argv[argc-1], O_RDWR, 0, 1);
 		if(!Dir){
 			fprintf(stderr,"Bad target\n");
 			exit(1);
 		}
 		get_name(argv[argc-1], filename, arg.mp.mcwd);
-		SubDir = descend(Dir, filename, 0, 0);
+		SubDir = descend(Dir, filename, 0, 0, 1);
 		if (!SubDir){
 			/* the last parameter is not a directory: take
 			 * it as the new name */
