@@ -17,7 +17,7 @@
 #include <math.h>
 
 #define tolinear(x) \
-(sector(x)-1+(head(x)+cyl(x)*used_dev.heads)*used_dev.sectors)
+(sector(x)-1+(head(x)+cyl(x)*used_dev->heads)*used_dev->sectors)
 
 
 static inline void print_hsc(hsc *h)
@@ -45,6 +45,82 @@ static void set_offset(hsc *h, int offset, int heads, int sectors)
 	h->cyl = cyl & 0xff;
 }
 
+
+
+int consistencyCheck(struct partition *partTable, int doprint, int verbose,
+		     int *has_activated, int *last_end, int *j, 
+		     struct device *used_dev, int target_partition)
+{
+	int i;
+	int inconsistency;
+	
+	*j = 0;
+	*last_end = 1;
+
+	/* quick consistency check */
+	inconsistency = 0;
+	*has_activated = 0;
+	for(i=1; i<5; i++){
+		if(!partTable[i].sys_ind)
+			continue;
+		if(partTable[i].boot_ind)
+			(*has_activated)++;
+		if((used_dev && 
+		    (used_dev->heads != head(partTable[i].end)+1 ||
+		     used_dev->sectors != sector(partTable[i].end))) ||
+		   sector(partTable[i].start) != 1){
+			fprintf(stderr,
+				"Partition %d is not aligned\n",
+				i);
+			inconsistency=1;
+		}
+		
+		if(*j && *last_end > BEGIN(partTable[i])) {
+			fprintf(stderr,
+				"Partitions %d and %d badly ordered or overlapping\n",
+				*j,i);
+			inconsistency=1;
+		}
+			
+		*last_end = END(partTable[i]);
+		*j = i;
+
+		if(used_dev &&
+		   tolinear(partTable[i].start) != BEGIN(partTable[i])) {
+			fprintf(stderr,
+				"Start position mismatch for partition %d\n",
+				i);
+			inconsistency=1;
+		}
+		if(used_dev &&
+		   tolinear(partTable[i].end)+1 != END(partTable[i])) {
+			fprintf(stderr,
+				"End position mismatch for partition %d\n",
+				i);
+			inconsistency=1;
+		}
+
+		if(doprint && verbose) {
+			if(i==target_partition)
+				putchar('*');
+			else
+				putchar(' ');
+			printf("Partition %d\n",i);
+
+			printf("  active=%x\n", partTable[i].boot_ind);
+			printf("  start:");
+			print_hsc(&partTable[i].start);
+			printf("  type=0x%x\n", partTable[i].sys_ind);
+			printf("  end:");
+			print_hsc(&partTable[i].end);
+			printf("  start=%d\n", BEGIN(partTable[i]));
+			printf("  nr=%d\n", _DWORD(partTable[i].nr_sects));
+			printf("\n");
+		}
+	}
+	return inconsistency;
+}
+
 /* setsize function.  Determines scsicam mapping if this cannot be inferred from
  * any existing partitions. Shamelessly snarfed from the Linux kernel ;-) */
 
@@ -490,9 +566,6 @@ void mpartition(int argc, char **argv, int dummy)
 		partTable[dev->partition].sys_ind = type;
 	}
 
-	j = 0;
-	last_end = 1;
-
 	if(activate) {
 		if(!partTable[dev->partition].sys_ind) {
 			fprintf(stderr,
@@ -510,63 +583,10 @@ void mpartition(int argc, char **argv, int dummy)
 		}
 	}
 
-	/* quick consistency check */
-	has_activated = 0;
-	for(i=1; i<5; i++){
-		if(!partTable[i].sys_ind)
-			continue;
-		if(partTable[i].boot_ind)
-			has_activated++;
-		if(used_dev.heads != head(partTable[i].end)+1 ||
-		   used_dev.sectors != sector(partTable[i].end) ||
-		   sector(partTable[i].start) != 1){
-			fprintf(stderr,
-				"Partition %d is not aligned\n",
-				i);
-			inconsistency=1;
-		}
-		
-		if(j && last_end > BEGIN(partTable[i])) {
-			fprintf(stderr,
-				"Partitions %d and %d badly ordered or overlapping\n",
-				j,i);
-			inconsistency=1;
-		}
-			
-		last_end = END(partTable[i]);
-		j = i;
 
-		if(tolinear(partTable[i].start) != BEGIN(partTable[i])) {
-			fprintf(stderr,
-				"Start position mismatch for partition %d\n",
-				i);
-			inconsistency=1;
-		}
-		if(tolinear(partTable[i].end)+1 != END(partTable[i])) {
-			fprintf(stderr,
-				"End position mismatch for partition %d\n",
-				i);
-			inconsistency=1;
-		}
-
-		if(doprint && verbose) {
-			if(i==dev->partition)
-				putchar('*');
-			else
-				putchar(' ');
-			printf("Partition %d\n",i);
-
-			printf("  active=%x\n", partTable[i].boot_ind);
-			printf("  start:");
-			print_hsc(&partTable[i].start);
-			printf("  type=0x%x\n", partTable[i].sys_ind);
-			printf("  end:");
-			print_hsc(&partTable[i].end);
-			printf("  start=%d\n", BEGIN(partTable[i]));
-			printf("  nr=%d\n", _DWORD(partTable[i].nr_sects));
-			printf("\n");
-		}
-	}
+	inconsistency |= consistencyCheck(partTable, doprint, verbose,
+					  &has_activated, &last_end, &j,
+					  &used_dev, dev->partition);
 
 	if(doprint && !inconsistency && partTable[dev->partition].sys_ind) {
 		printf("The following command will recreate the partition for drive %c:\n", 
