@@ -19,6 +19,9 @@
 #define _PASSWORD_LEN 33
 #endif
 
+#ifdef OS_linux
+#include <linux/fs.h>
+#endif
 
 static void usage(void)
 {
@@ -29,6 +32,7 @@ static void usage(void)
 		"Usage: %s [-V] [-q] [-e] [-r|-w|-p|-x] [drive:]\n"
 		"\t-q print status\n"
 		"\t-e eject disk\n"
+		"\t-f eject disk even when mounted\n"
 		"\t-r write protected (read-only)\n"
 		"\t-w not write-protected (read-write)\n"
 		"\t-p password write protected\n"
@@ -37,6 +41,46 @@ static void usage(void)
 	exit(1);
 }
 
+
+static int get_zip_status(int fd)
+{
+	unsigned char status[128];
+	unsigned char cdb[6] = { 0x06, 0, 0x02, 0, sizeof status, 0 };
+	
+	if (scsi_cmd(fd, cdb, 6, SCSI_IO_READ, 
+		     status, sizeof status) == -1) {
+		perror("status: ");
+		exit(1);
+	}
+	return status[21] & 0xf;
+}
+
+
+static int short_command(int fd, int cmd1, int cmd2, int cmd3, char *data)
+{
+	unsigned char cdb[6] = { 0, 0, 0, 0, 0, 0 };
+
+	cdb[0] = cmd1;
+	cdb[1] = cmd2;
+	cdb[4] = cmd3;
+
+	return scsi_cmd(fd, cdb, 6, SCSI_IO_WRITE, 
+			data, data ? strlen(data) : 0);
+}
+
+
+static int iomega_command(int fd, int mode, char *data)
+{
+	return short_command(fd, 
+			     SCSI_IOMEGA, mode, data ? strlen(data) : 0,
+			     data);
+}
+
+static int door_command(int fd, int cmd1, int cmd2)
+{
+	return short_command(fd, cmd1, 0, cmd2, 0);
+}
+
 void mzip(int argc, char **argv, int type)
 {
 	int c;
@@ -50,12 +94,16 @@ void mzip(int argc, char **argv, int type)
 	       ZIP_RW     = 1 << 2,
 	       ZIP_RO     = 1 << 3,
 	       ZIP_RO_PW  = 1 << 4,
-	       ZIP_PW     = 1 << 5
+	       ZIP_PW     = 1 << 5,
+	       ZIP_FORCE  = 1 << 6
 	} request = ZIP_NIX;
 	
 	/* get command line options */
-	while ((c = getopt(argc, argv, "epqrwx")) != EOF) {
+	while ((c = getopt(argc, argv, "efpqrwx")) != EOF) {
 		switch (c) {
+			case 'f':
+				request |= ZIP_FORCE;
+				break;
 			case 'e': /* eject */
 				request |= ZIP_EJECT;
 				break;
@@ -125,7 +173,7 @@ void mzip(int argc, char **argv, int type)
 		 * write-protected */		
 		if (fd == -1) 
 			continue;
-		fcntl(fd, F_SETFL, FD_CLOEXEC);
+		closeExec(fd);
 
 
 		if (!(request & (ZIP_RW | ZIP_RO | ZIP_RO_PW | 
@@ -179,93 +227,83 @@ void mzip(int argc, char **argv, int type)
 	
 	if (request & (ZIP_RW | ZIP_RO | ZIP_RO_PW | ZIP_PW)) {
 		int ret;
-		unsigned char status[128];
-		unsigned char cdb[6] = { 0x06, 0, 0x02, 0, sizeof status, 0 };
+		char *passwd, dummy[1];
+		int newmode;
 
-		if ((ret = scsi_cmd(fd, cdb, 6, SCSI_IO_READ, status, 
-				    sizeof status))) {
-			if (ret == -1) perror("status: ");
-			else fprintf(stderr, "can't read status\n");
-			exit(1);
+		/* unlock the disk by trying the tools disk password first */
+		if (get_zip_status(fd) & 0x01) {  /* unlock first */
+			char *s, *passwd;
+			passwd = "APlaceForYourStuff";
+			if ((s = strchr(passwd, '\n'))) *s = '\0';  /* chomp */
+			iomega_command(fd, 0, passwd);
 		}
-		
-		if (status[21] & 0x01) {  /* unlock first */
+
+		if (get_zip_status(fd) & 0x01) {  /* unlock first */
 			char *s, *passwd;
 			passwd = getpass("Password: ");
 			if ((s = strchr(passwd, '\n'))) *s = '\0';  /* chomp */
-			
-			memset(cdb, 0, sizeof cdb);
-			cdb[0] = SCSI_IOMEGA;
-			cdb[1] = 0x00;
-			cdb[4] = strlen(passwd);
-			
-			if ((ret = scsi_cmd(fd, cdb, 6, SCSI_IO_WRITE, 
-					    passwd, strlen(passwd)))) {
+			if((ret=iomega_command(fd, 0, passwd))){
 				if (ret == -1) perror("passwd: ");
 				else fprintf(stderr, "wrong password\n");
 				exit(1);
 			}
-		}
-		
-		if (request & (ZIP_RW | ZIP_RO | ZIP_RO_PW | ZIP_PW)) {
-			char *passwd, dummy[1];
-			
-			if (request & (ZIP_RO_PW | ZIP_PW)) {
-
-				char first_try[_PASSWORD_LEN];
-				
-				passwd = getpass("Enter new password:");
-				strncpy(first_try, passwd,_PASSWORD_LEN);
-				passwd = getpass("Re-type new password:");
-				if(strncmp(first_try, passwd, _PASSWORD_LEN)) {
-					fprintf(stderr,
-						"You mispelled it.  Password not set.\n");
-					exit(1);
-				}
-			} else {
-				passwd = dummy;
-				dummy[0] = '\0';
-			}
-			
-			memset(cdb, 0, sizeof cdb);
-			cdb[0] = SCSI_IOMEGA;
-			cdb[4] = strlen(passwd);
-			switch (request & 
-				(ZIP_RW | ZIP_RO | ZIP_RO_PW | ZIP_PW)) {
-				case ZIP_RW:    
-					cdb[1] = 0x00;
-					break;
-				case ZIP_RO:   
-					cdb[1] = 0x02;
-					break;
-				case ZIP_RO_PW:
-					cdb[1] = 0x03;
-					break;
-				case ZIP_PW:  
-					cdb[1] = 0x05;
-					break;
-			}
-			
-			if ((ret = scsi_cmd(fd, cdb, 6, SCSI_IO_WRITE,
-					    passwd, strlen(passwd)))){
-				if (ret == -1) perror("set passwd: ");
-				else fprintf(stderr, "password not changed\n");
+			if(get_zip_status(fd) & 0x01) {
+				fprintf(stderr, "wrong password\n");
 				exit(1);
 			}
 		}
+		
+		if (request & (ZIP_RO_PW | ZIP_PW)) {			
+			char first_try[_PASSWORD_LEN];
+			
+			passwd = getpass("Enter new password:");
+			strncpy(first_try, passwd,_PASSWORD_LEN);
+			passwd = getpass("Re-type new password:");
+			if(strncmp(first_try, passwd, _PASSWORD_LEN)) {
+				fprintf(stderr,
+					"You mispelled it. Password not set.\n");
+				exit(1);
+			}
+		} else {
+			passwd = dummy;
+			dummy[0] = '\0';
+		}
+			
+		switch (request & 
+			(ZIP_RW | ZIP_RO | ZIP_RO_PW | ZIP_PW)) {
+			case ZIP_RW:    
+				newmode = 0x00;
+				break;
+			case ZIP_RO:   
+				newmode = 0x02;
+				break;
+			case ZIP_RO_PW:
+				newmode = 0x03;
+				break;
+			case ZIP_PW:  
+				newmode = 0x05;
+				break;
+			default:
+				newmode = 0;
+				break;
+		}
+			
+		if((ret=iomega_command(fd, newmode, passwd))){
+			if (ret == -1) perror("set passwd: ");
+			else fprintf(stderr, "password not changed\n");
+			exit(1);
+		}
+#ifdef OS_linux
+		ioctl(fd, BLKRRPART); /* revalidate the disk, so that the
+					 kernel notices that its writable
+					 status has changed */
+#endif
 	}
 	
 	if (request & ZIP_STATUS) {
-		unsigned char status[128];
-		unsigned char cdb[6] = { 0x06, 0, 0x02, 0, sizeof status, 0 };
+		int status;
 		
-		if (scsi_cmd(fd, cdb, 6, SCSI_IO_READ, 
-			     status, sizeof status) == -1) {
-			perror("status: ");
-			exit(1);
-		}
-		
-		switch (status[21] & 0x0f) {
+		switch (status = get_zip_status(fd)) {
 			case 0:  
 				printf("Drive '%c:' is not write-protected\n", 
 				       drive);
@@ -284,34 +322,31 @@ void mzip(int argc, char **argv, int type)
 				break;
 			default: 
 				printf("Unknown protection mode %d of drive '%c:'\n",
-				       status[24] & 0x0f, drive);
-				break;
-		}
+				       status, drive);
+				break;				
+		}		
 	}
 	
 	if (request & ZIP_EJECT) {
-		unsigned char cdb[6] = { 0, 0, 0, 0, 0, 0 };
-		
-		cdb[0] = SCSI_ALLOW_MEDIUM_REMOVAL;
-		cdb[4] = 0;
-		if (scsi_cmd(fd, cdb, 6, SCSI_IO_WRITE, 0, 0) == -1) {
-			perror("door unlock: ");
-			exit(1);
-		}
-		
-		cdb[0] = SCSI_START_STOP;
-		cdb[4] = 1;
-		if (scsi_cmd(fd, cdb, 6, SCSI_IO_WRITE, 0, 0) == -1) {
+		if(request & ZIP_FORCE)
+			if(door_command(fd, SCSI_ALLOW_MEDIUM_REMOVAL, 0) < 0) {
+				perror("door unlock: ");
+				exit(1);
+			}
+
+		if(door_command(fd, SCSI_START_STOP, 1) < 0) {
 			perror("stop motor: ");
 			exit(1);
 		}
-		
-		cdb[0] = SCSI_START_STOP;
-		cdb[4] = 2;
-		if (scsi_cmd(fd, cdb, 6, SCSI_IO_WRITE, 0, 0) == -1){
+
+		if(door_command(fd, SCSI_START_STOP, 2) < 0) {
 			perror("eject: ");
 			exit(1);
 		}
+		if(door_command(fd, SCSI_START_STOP, 2) < 0) {
+			perror("second eject: ");
+			exit(1);
+		}
 	}
 	
 	close(fd);
