@@ -89,8 +89,8 @@ int lock_dev(int fd, int mode, struct device *dev)
 
 typedef int (*iofn) (int, char *, int);
 
-static int f_io(Stream_t *Stream, char *buf, int where, int len,
-		iofn io)
+static int file_io(Stream_t *Stream, char *buf, int where, int len,
+		   iofn io)
 {
 	DeclareThis(SimpleFile_t);
 	int ret;
@@ -115,17 +115,17 @@ static int f_io(Stream_t *Stream, char *buf, int where, int len,
 	
 
 
-static int f_read(Stream_t *Stream, char *buf, off_t where, size_t len)
+static int file_read(Stream_t *Stream, char *buf, off_t where, size_t len)
 {	
-	return f_io(Stream, buf, where, len, (iofn) read);
+	return file_io(Stream, buf, where, len, (iofn) read);
 }
 
-static int f_write(Stream_t *Stream, char *buf, off_t where, size_t len)
+static int file_write(Stream_t *Stream, char *buf, off_t where, size_t len)
 {
-	return f_io(Stream, buf, where, len, (iofn) write);
+	return file_io(Stream, buf, where, len, (iofn) write);
 }
 
-static int f_flush(Stream_t *Stream)
+static int file_flush(Stream_t *Stream)
 {
 #if 0
 	DeclareThis(SimpleFile_t);
@@ -135,7 +135,7 @@ static int f_flush(Stream_t *Stream)
 	return 0;
 }
 
-static int f_free(Stream_t *Stream)
+static int file_free(Stream_t *Stream)
 {
 	DeclareThis(SimpleFile_t);
 
@@ -145,9 +145,9 @@ static int f_free(Stream_t *Stream)
 		return 0;
 }
 
-static int f_geom(Stream_t *Stream, struct device *dev, 
-		  struct device *orig_dev,
-		  int media, struct bootsector *boot)
+static int file_geom(Stream_t *Stream, struct device *dev, 
+		     struct device *orig_dev,
+		     int media, struct bootsector *boot)
 {
 	int ret;
 	DeclareThis(SimpleFile_t);
@@ -205,7 +205,7 @@ static int f_geom(Stream_t *Stream, struct device *dev,
 	dev->sectors = dev->sectors * WORD(secsiz) / 512;
 
 #ifdef JPD
-	printf("f_geom:media=%0X=>cyl=%d,heads=%d,sects=%d,ssize=%d,use2m=%X\n",
+	printf("file_geom:media=%0X=>cyl=%d,heads=%d,sects=%d,ssize=%d,use2m=%X\n",
 	       media, dev->tracks, dev->heads, dev->sectors, dev->ssize,
 	       dev->use_2m);
 #endif
@@ -218,8 +218,8 @@ static int f_geom(Stream_t *Stream, struct device *dev,
 }
 
 
-static int f_data(Stream_t *Stream, long *date, size_t *size,
-		  int *type, int *address)
+static int file_data(Stream_t *Stream, long *date, size_t *size,
+		     int *type, int *address)
 {
 	DeclareThis(SimpleFile_t);
 
@@ -237,10 +237,10 @@ static int f_data(Stream_t *Stream, long *date, size_t *size,
 /* ZIP or other scsi device on Solaris or SunOS system.
    Since Sun won't accept a non-Sun label on a scsi disk, we must
    bypass Sun's disk interface and use low-level SCSI commands to read
-   or write the ZIP drive.  We thus replace the f_read and f_write routines
-   with our own scsi_read and scsi_write routines, that use the uscsi ioctl
-   interface.  By James Dugal, jpd@usl.edu, 11-96.  Tested under Solaris
-   2.5 and SunOS 4.3.1_u1 using GCC.
+   or write the ZIP drive.  We thus replace the file_read and file_write
+   routines with our own scsi_read and scsi_write routines, that use the
+   uscsi ioctl interface.  By James Dugal, jpd@usl.edu, 11-96.  Tested
+   under Solaris 2.5 and SunOS 4.3.1_u1 using GCC.
 
    Note: the mtools.conf entry for a ZIP drive would look like this:
 (solaris) drive C: file="/dev/rdsk/c0t5d0s2" partition=4  FAT=16 nodelay  exclusive scsi=&
@@ -258,17 +258,17 @@ static scsi_sector_size=512;
 
 static void scsi_init(int fd)
 {
-   unsigned char cdb[6],buf[255];
+   unsigned char cdb[6],buf[8];
 
-   memset(&cdb, 0, sizeof cdb);
-   memset(buf,0,255);
-   cdb[0]=SCSI_MODE_SENSE;
-   cdb[4]=255;
-   if (scsi_cmd(fd, (unsigned char *)cdb, 6, SCSI_IO_READ, buf,255)==0)
+   memset(cdb, 0, sizeof cdb);
+   memset(buf,0, sizeof(buf));
+   cdb[0]=SCSI_READ_CAPACITY;
+   if (scsi_cmd(fd, (unsigned char *)cdb, 
+		sizeof(cdb), SCSI_IO_READ, buf, sizeof(buf))==0)
    {
        scsi_sector_size=
-	   ((unsigned)buf[9]<<16)|((unsigned)buf[10]<<8)|(unsigned)buf[11];
-       if (scsi_sector_size>512)
+	       ((unsigned)buf[5]<<16)|((unsigned)buf[6]<<8)|(unsigned)buf[7];
+       if (scsi_sector_size != 512)
 	   fprintf(stderr,"  (scsi_sector_size=%d)\n",scsi_sector_size);
    }
 }
@@ -284,7 +284,7 @@ int scsi_io(Stream_t *Stream, char *buf,  off_t where, size_t len, int rwcmd)
 	/* 512,1024,2048,... bytes/sector supported */
 	offset=where + This->offset - firstblock*scsi_sector_size;
 	nsect=(offset+len+scsi_sector_size-1)/scsi_sector_size;
-#if defined(sun) && defined(i386)
+#if defined(OS_sun) && defined(OS_i386)
 	if (scsi_sector_size>512)
 		firstblock*=scsi_sector_size/512; /* work around a uscsi bug */
 #endif /* sun && i386 */
@@ -317,7 +317,7 @@ int scsi_io(Stream_t *Stream, char *buf,  off_t where, size_t len, int rwcmd)
 		nsect=max;
 	
 	/* set up SCSI READ/WRITE command */
-	memset(&cdb, 0, sizeof cdb);
+	memset(cdb, 0, sizeof cdb);
 
 	switch(rwcmd) {
 		case SCSI_IO_READ:
@@ -406,20 +406,20 @@ int scsi_write(Stream_t *Stream, char *buf, off_t where, size_t len)
 static Class_t ScsiClass = {
 	scsi_read, 
 	scsi_write,
-	f_flush,
-	f_free,
-	f_geom,
-	f_data
+	file_flush,
+	file_free,
+	file_geom,
+	file_data
 };
 
 
 static Class_t SimpleFileClass = {
-	f_read, 
-	f_write,
-	f_flush,
-	f_free,
-	f_geom,
-	f_data
+	file_read, 
+	file_write,
+	file_flush,
+	file_free,
+	file_geom,
+	file_data
 };
 
 
@@ -472,12 +472,8 @@ Stream_t *SimpleFileOpen(struct device *dev, struct device *orig_dev,
 		return NULL;
 	}
 
-	fcntl(This->fd, F_SETFL, FD_CLOEXEC);
+	closeExec(This->fd);
 
-/* this didn't work on BeOS, so I just removed it */
-#ifdef __BEOS__
-	if(strcmp("/dev/floppy_disk",name))
-#endif
 	if (fstat(This->fd, &This->stat) < 0){
 		Free(This);
 		if(errmsg)
@@ -494,7 +490,7 @@ Stream_t *SimpleFileOpen(struct device *dev, struct device *orig_dev,
 		if(errmsg)
 			sprintf(errmsg,
 				"plain floppy: device \"%s\" busy:",
-				dev->name);
+				dev ? dev->name : "unknown");
 		return NULL;
 	}
 		
@@ -532,6 +528,7 @@ Stream_t *SimpleFileOpen(struct device *dev, struct device *orig_dev,
 	}
 	while(!(mode2 & NO_OFFSET) &&
 	      dev && dev->partition && dev->partition <= 4) {
+		int has_activated, last_end, j;
 		unsigned char buf[2048];
 		struct partition *partTable=(struct partition *)(buf+ 0x1ae);
 		
@@ -557,6 +554,16 @@ Stream_t *SimpleFileOpen(struct device *dev, struct device *orig_dev,
 				cyl(partTable[dev->partition].start)+1;
 		}
 		dev->hidden=dev->sectors*head(partTable[dev->partition].start);
+		if(consistencyCheck((struct partition *)(buf+0x1ae), 0, 0,
+				    &has_activated, &last_end, &j, dev, 0)) {
+			fprintf(stderr,
+				"Warning: inconsistent partition table\n");
+			fprintf(stderr,
+				"Possibly unpartitioned device\n");
+			fprintf(stderr,
+				"\n*** Maybe try without partition=%d in device definition ***\n\n",
+				dev->partition);
+		}
 		break;
 		/* NOTREACHED */
 	}
