@@ -50,7 +50,7 @@ static void init_streamcache(void)
 
 
 Stream_t *open_subdir(MainParam_t *mp, const char *arg, 
-		      int flags,int mode)
+		      int flags,int mode, int lock)
 {
 	int drive;
 	Stream_t *Fs;
@@ -82,7 +82,7 @@ Stream_t *open_subdir(MainParam_t *mp, const char *arg,
 	    strcasecmp(pathname,subdir_name)){
 		FREE(&Subdir);
 		
-		Subdir = subdir(Fs, pathname);
+		Subdir = subdir(Fs, pathname, lock);
 		last_drive = drive;
 		strcpy(subdir_name, pathname);
 	}
